/*
 Data: 19-4-2016
 Komunikacja MODBUS Master
 Opis: MIC488 odczytuje i zapisuje rejestry z innych urzdzen przez protoko MODBUS RTU

  MIC488 moe dziaa w trybie Modbus-Master na porcie COM2
 (Konfiguracja->Komunikacja-> Port COM2 (RS485) -> Modbus Master zaznaczone)

  Orientacyjne czasy wykonywania poszczegolnych funkjci dla baudrate 38400:
  MODBUSR_IN,  MODBUSR_OUT:               -> 5 ms
  MODBUSR_I,  MODBUSR_DI:                 -> 6 ms
  MODBUSW_OUT, MODBUSW_I, MODBUSW_W:      -> 7 ms
  MODBUSW_DI,  MODBUSW_DW,  MODBUSW_REAL: -> 7 ms


  ======== Funkcje zapisu przez Modbus ============
  REG_ADDR - przykladowy adres rejestru slave
  VALUE - przykladowa wartosc do zapisu / odczytu
  
  MODBUSW_OUT(SLAVE_ID, REG_ADDR, VALUE)        <- Zapis wyjscia (funkcja 0x05)
  MODBUSW_I(SLAVE_ID, REG_ADDR, VALUE)          <- Zapis rejestru typu INT   (funkcja 0x06)     
  MODBUSW_DI(SLAVE_ID, REG_ADDR, VALUE)         <- Zapis rejestru typu DINT  (funkcja 0x10)   
  MODBUSW_W(SLAVE_ID, REG_ADDR, VALUE)          <- Zapis rejestru typu WORD  (funkcja 0x06)
  MODBUSW_DW(SLAVE_ID, REG_ADDR, VALUE)         <- Zapis rejestru typu DWORD (funkcja 0x10)
  MODBUSW_REAL(SLAVE_ID, REG_ADDR, VALUE)       <- Zapis rejestru typu REAL  (funkcja 0x10)

  ======== Funkcje odczytu przez Modbus ===========
  SET VALUE = MODBUSR_IN(SLAVE_ID, REG_ADDR)    <- Odczyt wejscia (funkcja 0x02) 
  SET VALUE = MODBUSR_OUT(SLAVE_ID, REG_ADDR)   <- Odczyt wejscia (funkcja 0x01) 
  SET VALUE = MODBUSR_I(SLAVE_ID, REG_ADDR)     <- Odczyt rejestru typu INT  (funkcja 0x03)
  SET VALUE = MODBUSR_DI(SLAVE_ID, REG_ADDR)    <- Odczyt rejestru typu DINT (funkcja 0x03)
  SET VALUE = MODBUSR_W(SLAVE_ID, REG_ADDR)     <- Odczyt rejestru typu WORD (funkcja 0x03)
  SET VALUE = MODBUSR_DW(SLAVE_ID, REG_ADDR)    <- Odczyt rejestru typu DWORD (funkcja 0x03)
  SET VALUE = MODBUSR_REAL(SLAVE_ID, REG_ADDR)  <- Odczyt rejestru typu REAL (funkcja 0x03)
*/

#SLAVE_ID 1         // Zdefiniowany adres slave dla urzdzenia slave
#REJESTR_A  0       // Przykadowy rejestr urzadzenia
#REJESTR_B  1       // Przykadowy rejestr urzadzenia
#REJESTR_C  2       // Przykadowy rejestr urzadzenia
#REJESTR_D  100     // Przykadowy rejestr urzadzenia
#REJESTR_E  101     // Przykadowy rejestr urzadzenia

SET VALUE = 0

MAIN:

    DELAY 0.1
    
    MODBUSW_OUT(SLAVE_ID, REJESTR_D, ON)        // Zalaczamy wyjscie o adresie REJESTR_C 

    MODBUSW_OUT(SLAVE_ID, REJESTR_E, IN1)       // Sterujemy wyjsciem adresie REJESTR_D zaleznie od wejscia IN1 sterownika
    
    MODBUSW_I(SLAVE_ID, REJESTR_A, VALUE)       // Zapisujemy do rejestru REJESTR_A wartosc zmiennej VALUE
  
    SET NOWA =  MODBUSR_I(SLAVE_ID, REJESTR_B)  // Odczytujemy rejestr o adresie REJESTR_B 
    
    MODBUSW_I(SLAVE_ID, REJESTR_C, NOWA)        // Zapisujemy do rejestru REJESTR_C wartosc zmiennej NOWA odczytanej z rejestru wyzej

    
JUMP MAIN



















